==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","");
define("_LVOTES","ʴ");
define("_HITS","ӹǹ駼ҹ");
define("_TOPWELCOME","Welcome to the TOP page for");
define("_READSTORIES","most read stories");
define("_COMMENTEDSTORIES","most commented stories");
define("_ACTIVECAT","most active categories");
define("_READSECTION","most read articles in special sections");
define("_NEWSSUBMITTERS","most active news submitters");
define("_NEWSSENT","news sent");
define("_VOTEDPOLLS","most voted polls");
define("_MOSTACTIVEAUTHORS","most active authors");
define("_NEWSPUBLISHED","news published");
define("_READREVIEWS","most read reviews");
define("_DOWNLOADEDFILES","most downloaded files");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","");
define("_LVOTES","ʴ");
define("_HITS","ӹǹ駼ҹ");
define("_TOPWELCOME","Welcome to the TOP page for");
define("_READSTORIES","most read stories");
define("_COMMENTEDSTORIES","most commented stories");
define("_ACTIVECAT","most active categories");
define("_READSECTION","most read articles in special sections");
define("_NEWSSUBMITTERS","most active news submitters");
define("_NEWSSENT","news sent");
define("_VOTEDPOLLS","most voted polls");
define("_MOSTACTIVEAUTHORS","most active authors");
define("_NEWSPUBLISHED","news published");
define("_READREVIEWS","most read reviews");
define("_DOWNLOADEDFILES","most downloaded files");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
